@@ -1,4 +1,4 @@
-#  Copyright 2008-2012 Nokia Siemens Networks Oyj
+#  Copyright 2008-2015 Nokia Solutions and Networks
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -15,7 +15,7 @@
 import re
 
 from robotide.robotapi import is_var
-from robotide.utils import find_variable_basenames, is_scalar_variable
+from robotide.utils import variablematcher
 
 
 def parse_arguments_to_var_dict(args, name):
@@ -25,17 +25,18 @@ def parse_arguments_to_var_dict(args, name):
         if parsed:
             result[parsed[0]] = parsed[1]
     if not args and name:
-        for var in find_variable_basenames(name):
-            if is_scalar_variable(var):
+        for var in variablematcher.find_variable_basenames(name):
+            if variablematcher.is_scalar_variable(var):
                 result[var] = None
     return result
 
 default_val_regexp = re.compile(r'([$@]\{.*\})\s*=\s*(.*)')
 
+
 def parse_argument(argument):
     match = default_val_regexp.match(argument)
     if match:
         return (match.group(1), match.group(2))
     if is_var(argument):
         return (argument, None)
-    return None
\ No newline at end of file
+    return None
