@@ -1,4 +1,4 @@
-#  Copyright 2008-2012 Nokia Siemens Networks Oyj
+#  Copyright 2008-2015 Nokia Solutions and Networks
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -12,10 +12,10 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from robot.running.userkeyword import EmbeddedArgsTemplate
+from robotide import robotapi
 
 
-class EmbeddedArgsHandler(EmbeddedArgsTemplate):
+class EmbeddedArgsHandler(robotapi.EmbeddedArgsTemplate):
 
     def __init__(self, keyword):
         if keyword.arguments:
