@@ -13,6 +13,9 @@
 #  limitations under the License.
 
 import wx
+import textwrap
+
+from robotide.widgets import HelpLabel, Label, TextField
 
 
 class PreferencesPanel(wx.Panel):
@@ -89,3 +92,62 @@ class PreferencesColorPicker(wx.ColourPickerCtrl):
         super(PreferencesColorPicker, self).SetColour(colour)
         self.settings[self.key] = colour
         self.settings.save()
+
+
+class _ChoiceEditor(object):
+    _editor_class = None
+
+    def __init__(self, settings, setting_name, label, choices, help=''):
+        self._settings = settings
+        self._setting_name = setting_name
+        self._label = label
+        self._choices = choices
+        self._help = help
+
+    def chooser(self, parent):
+        return self._editor_class(parent, wx.ID_ANY, self._settings,
+                                  key=self._setting_name, choices=self._choices)
+
+    def label(self, parent):
+        return wx.StaticText(parent, wx.ID_ANY, self._label)
+
+    def help(self, parent):
+        return HelpLabel(parent, '\n'.join(textwrap.wrap(self._help, 60)))
+
+
+class StringChoiceEditor(_ChoiceEditor):
+    _editor_class = PreferencesComboBox
+
+
+class IntegerChoiceEditor(_ChoiceEditor):
+    _editor_class = IntegerPreferenceComboBox
+
+
+def boolean_editor(parent, settings, name, label, help=''):
+    editor = _create_checkbox_editor(parent, settings, name, help)
+    label = Label(parent, label=label)
+    return label, editor
+
+
+def _create_checkbox_editor(parent, settings, name, help):
+    initial_value = settings[name]
+    editor = wx.CheckBox(parent)
+    editor.SetValue(initial_value)
+    editor.Bind(wx.EVT_CHECKBOX,
+                lambda evt: settings.set(name, editor.GetValue()))
+    editor.SetToolTipString(help)
+    return editor
+
+
+def comma_separated_value_editor(parent, settings, name, label, help=''):
+    initial_value = ', '.join(settings[name])
+    editor = TextField(parent, initial_value)
+    editor.SetToolTipString(help)
+
+    def set_value():
+        new_value = [token.strip() for token in editor.GetValue().split(',')
+                     if token.strip()]
+        settings.set(name, new_value)
+    editor.Bind(wx.EVT_KILL_FOCUS, lambda evt: set_value())
+
+    return Label(parent, label=label), editor
